@@ -1,13 +1,11 @@
 from functools import partial
-import http
 from http.server import BaseHTTPRequestHandler, HTTPServer
 import os
+import psutil
 import signal
 import threading
 import traceback
 
-import psutil
-
 from adam.config import Config
 from adam.sso.idp import Idp
 from adam.app_session import AppSession, IdpLogin
@@ -27,15 +25,22 @@ class TokenHandler(BaseHTTPRequestHandler):
     def do_GET(self):
         print('cient', self.client_address)
         print('ports', TokenHandler.get_ports())
-        self.send_response(200)
-        self.send_header('Content-type', 'text/plain')
-        self.end_headers()
-        self.wfile.write(self.idp_token.encode('utf8'))
+        if self.client_address[1] in TokenHandler.get_ports():
+            self.send_response(200)
+            self.send_header('Content-type', 'text/plain')
+            self.end_headers()
+            self.wfile.write(self.idp_token.encode('utf8'))
+        else:
+            self.send_response(403)
+            self.send_header('Content-type', 'text/plain')
+            self.end_headers()
+            self.wfile.write(f'Port: {self.client_address[1]} has not been opened by the process.'.encode('utf8'))
 
     def get_ports():
         ports = []
 
         for p in TokenHandler.get_all_child_processes():
+            print('SEAN', p.pid)
             ports.extend(TokenHandler.get_open_ports_by_pid(p.pid))
 
         return ports
