@@ -24,9 +24,9 @@ class Idp:
             if l0 := session.login_from_env_var():
                 return l0
         if p := os.getenv("SERVER_PORT"):
-            res: requests.Response = requests.get(f'localhost:{p}')
+            res: requests.Response = requests.get(f'http://localhost:{p}')
             if res.status_code == 200 and res.text:
-                return res.text
+                return session.login_from_token(res.text)
 
         r: IdpLogin = None
         try:
